@@ -217,32 +217,32 @@ class S3ToSqs(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3BucketInterface")
     def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
         return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
         return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], jsii.get(self, "encryptionKey"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
@@ -306,15 +306,15 @@ class S3ToSqsProps:
         :summary: The properties for the S3ToSqs class.
         '''
         if isinstance(bucket_props, dict):
-            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+            bucket_props = BucketProps(**bucket_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = QueueProps(**dead_letter_queue_props)
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
+            encryption_key_props = KeyProps(**encryption_key_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
+            logging_bucket_props = BucketProps(**logging_bucket_props)
         if isinstance(queue_props, dict):
-            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
+            queue_props = QueueProps(**queue_props)
         if __debug__:
             type_hints = typing.get_type_hints(S3ToSqsProps.__init__)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
